@@ -32,8 +32,6 @@
 ##' direct descendants ("children"), all extant descendants ("tips"), or all
 ##' descendant nodes ("all") or all descendant nodes including self ("ALL").
 ##' @param include.self whether to include self in list of siblings
-##' @param \dots a list of node numbers or names, or a vector of node numbers or
-##' names
 ##' @return \describe{
 ##' \item{\code{ancestors}}{ return a named vector (or a list
 ##' of such vectors in the case of multiple input nodes) of the
@@ -125,7 +123,8 @@ descendants <- function (phy, node, type=c("tips","children","all", "ALL")) {
         descendant <- as.integer(edge[, 2])
 
         ## return indicator matrix of ALL descendants (including self)
-        isDes <- .Call("descendants_c", node, ancestor, descendant)
+        isDes <- .Call("descendants_c", node, ancestor, descendant,
+                       PACKAGE = "phylobase")
         storage.mode(isDes) <- "logical"
 
         if (type == "all") {
@@ -204,7 +203,8 @@ ancestors <- function (phy, node, type=c("all","parent","ALL")) {
         descendant <- as.integer(edge[, 2])
 
         ## return indicator matrix of ALL ancestors (including self)
-        isAnc <- .Call("ancestors_c", node, ancestor, descendant)
+        isAnc <- .Call("ancestors_c", node, ancestor, descendant,
+                       PACKAGE = "phylobase")
         storage.mode(isAnc) <- "logical"
 
         ## drop self if needed
